==> flink-table-common-1.10.0-sources.jar: org/apache/flink/table/descriptors/Descriptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.descriptors;

import org.apache.flink.annotation.PublicEvolving;

import java.util.Map;

/**
 * Interface that adds a set of string-based, normalized properties for describing DDL information.
 *
 * <p>Typical characteristics of a descriptor are:
 * - descriptors have a default constructor
 * - descriptors themselves contain very little logic
 * - corresponding validators validate the correctness (goal: have a single point of validation)
 *
 * <p>A descriptor is similar to a builder in a builder pattern, thus, mutable for building
 * properties.
 */
@PublicEvolving
public interface Descriptor {

	/**
	 * Converts this descriptor into a set of properties.
	 */
	Map<String, String> toProperties();
}

==> flink-table-common-1.13.6-sources.jar: org/apache/flink/table/descriptors/Descriptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.descriptors;

import org.apache.flink.annotation.PublicEvolving;

import java.util.Map;

/**
 * Interface that adds a set of string-based, normalized properties for describing DDL information.
 *
 * <p>Typical characteristics of a descriptor are: - descriptors have a default constructor -
 * descriptors themselves contain very little logic - corresponding validators validate the
 * correctness (goal: have a single point of validation)
 *
 * <p>A descriptor is similar to a builder in a builder pattern, thus, mutable for building
 * properties.
 */
@PublicEvolving
public interface Descriptor {

    /** Converts this descriptor into a set of properties. */
    Map<String, String> toProperties();
}
